PbTrainingDisplayItem

Enum PbTrainingDisplayItem 

#[repr(i32)]
pub enum PbTrainingDisplayItem {
Show 85 variants TimeOfDay = 2, Stopwatch = 3, CurrentLapTime = 6, LastLapTime = 7, LastAutomaticLapTime = 8, Altitude = 10, Ascent = 11, Descent = 12, Inclinometer = 13, Temperature = 15, CurrentLapAscent = 16, CurrentLapDescent = 17, CurrentLapVam = 18, CurrentHeartRate = 20, AverageHeartRate = 21, MaximumHeartRate = 22, CurrentLapAverageHeartRate = 24, CurrentLapMaxHeartRate = 25, PreviousLapAverageHeartRate = 26, PreviousLapMaxHeartRate = 28, Calories = 27, ZonePointer = 32, TimeInZone = 33, RrVariation = 35, Distance = 37, CurrentLapDistance = 38, PreviousLapDistance = 39, SpeedOrPace = 41, SpeedOrPaceAverage = 42, SpeedOrPaceMaximum = 43, CurrentLapSpeedOrPace = 44, SpeedZonePointer = 45, TimeInSpeedZone = 46, CurrentLapMaxPaceOrSpeed = 47, PreviousLapMaxPaceOrSpeed = 48, PreviousLapSpeedOrPace = 220, VerticalSpeedMovingAverage = 221, Cadence = 49, AverageCadence = 50, MaximumCadence = 240, CurrentLapCadence = 51, CurrentLapMaxCadence = 52, PreviousLapCadence = 53, StrideLength = 54, AverageStrideLength = 55, CurrentPower = 56, CurrentPowerLeftRightBalance = 57, MaximumForce = 58, PowerZonePointer = 59, AveragePower = 60, MaximumPower = 61, AveragePowerLeftRightBalance = 62, CurrentLapAveragePower = 63, CurrentLapMaximumPower = 64, CurrentLapAveragePowerLrBalance = 65, TimeInPowerZone = 66, PreviousLapAveragePower = 67, PreviousLapMaximumPower = 68, PreviousLapAveragePowerLrBalance = 230, RestTime = 69, PoolCounter = 70, MultisportDuration = 88, MultisportDistance = 89, MultisportCalories = 90, MultisportAscent = 91, MultisportDescent = 92, HeartRateZones = 100, MultisportHeartRateZones = 101, LocationGuide = 102, PowerZones = 103, ForceGraph = 104, TimeBasedSpeedZones = 105, CurrentAlapAverageHeartRate = 200, CurrentAlapTime = 201, CurrentAlapAveragePower = 202, CurrentAlapMaximumPower = 203, CurrentAlapSpeedOrPace = 204, CurrentAlapDistance = 205, CurrentAlapAscent = 206, CurrentAlapDescent = 207, CurrentAlapCadence = 208, CurrentAlapAveragePowerLrBalance = 209, CurrentAlapMaxHeartRate = 210, CurrentAlapMaxSpeed = 211, CurrentAlapMaxCadence = 212,
}

Variants



TimeOfDay = 2



Stopwatch = 3



CurrentLapTime = 6



LastLapTime = 7



LastAutomaticLapTime = 8



Altitude = 10



Ascent = 11



Descent = 12



Inclinometer = 13



Temperature = 15



CurrentLapAscent = 16



CurrentLapDescent = 17



CurrentLapVam = 18



CurrentHeartRate = 20



AverageHeartRate = 21



MaximumHeartRate = 22



CurrentLapAverageHeartRate = 24



CurrentLapMaxHeartRate = 25



PreviousLapAverageHeartRate = 26



PreviousLapMaxHeartRate = 28



Calories = 27



ZonePointer = 32



TimeInZone = 33



RrVariation = 35



Distance = 37



CurrentLapDistance = 38



PreviousLapDistance = 39



SpeedOrPace = 41



SpeedOrPaceAverage = 42



SpeedOrPaceMaximum = 43



CurrentLapSpeedOrPace = 44



SpeedZonePointer = 45



TimeInSpeedZone = 46



CurrentLapMaxPaceOrSpeed = 47



PreviousLapMaxPaceOrSpeed = 48



PreviousLapSpeedOrPace = 220



VerticalSpeedMovingAverage = 221



Cadence = 49



AverageCadence = 50



MaximumCadence = 240



CurrentLapCadence = 51



CurrentLapMaxCadence = 52



PreviousLapCadence = 53



StrideLength = 54



AverageStrideLength = 55



CurrentPower = 56



CurrentPowerLeftRightBalance = 57



MaximumForce = 58



PowerZonePointer = 59



AveragePower = 60



MaximumPower = 61



AveragePowerLeftRightBalance = 62



CurrentLapAveragePower = 63



CurrentLapMaximumPower = 64



CurrentLapAveragePowerLrBalance = 65



TimeInPowerZone = 66



PreviousLapAveragePower = 67



PreviousLapMaximumPower = 68



PreviousLapAveragePowerLrBalance = 230



RestTime = 69



PoolCounter = 70



MultisportDuration = 88



MultisportDistance = 89



MultisportCalories = 90



MultisportAscent = 91



MultisportDescent = 92



HeartRateZones = 100



MultisportHeartRateZones = 101



LocationGuide = 102



PowerZones = 103



ForceGraph = 104



TimeBasedSpeedZones = 105



CurrentAlapAverageHeartRate = 200



CurrentAlapTime = 201



CurrentAlapAveragePower = 202



CurrentAlapMaximumPower = 203



CurrentAlapSpeedOrPace = 204



CurrentAlapDistance = 205



CurrentAlapAscent = 206



CurrentAlapDescent = 207



CurrentAlapCadence = 208



CurrentAlapAveragePowerLrBalance = 209



CurrentAlapMaxHeartRate = 210



CurrentAlapMaxSpeed = 211



CurrentAlapMaxCadence = 212

Implementations

Source

impl PbTrainingDisplayItem

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PbTrainingDisplayItem.

pub fn from_i32(value: i32) -> Option<PbTrainingDisplayItem>

Converts an i32 to a PbTrainingDisplayItem, or None if value is not a valid variant.