pub struct PbGeneralPreferences {
pub localization_preferences: Option<PbLocalizationPreferences>,
pub training_preferences: Option<PbTrainingPreferences>,
pub activity_goal_preferences: Option<PbActivityGoalPreferences>,
pub last_modified: PbSystemDateTime,
}Fields
localization_preferences: Option<PbLocalizationPreferences>training_preferences: Option<PbTrainingPreferences>activity_goal_preferences: Option<PbActivityGoalPreferences>last_modified: PbSystemDateTimeTrait Implementations
Sourceimpl Clone for PbGeneralPreferences
impl Clone for PbGeneralPreferences
Sourcefn clone(&self) -> PbGeneralPreferences
fn clone(&self) -> PbGeneralPreferences
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbGeneralPreferences
impl Debug for PbGeneralPreferences
Sourceimpl Default for PbGeneralPreferences
impl Default for PbGeneralPreferences
Sourcefn default() -> PbGeneralPreferences
fn default() -> PbGeneralPreferences
Returns the “default value” for a type. Read more
Sourceimpl Message for PbGeneralPreferences
impl Message for PbGeneralPreferences
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbGeneralPreferences
impl PartialEq for PbGeneralPreferences
impl StructuralPartialEq for PbGeneralPreferences