pub struct PbUserDeviceAutoSyncSettings {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for PbUserDeviceAutoSyncSettings
impl Clone for PbUserDeviceAutoSyncSettings
Sourcefn clone(&self) -> PbUserDeviceAutoSyncSettings
fn clone(&self) -> PbUserDeviceAutoSyncSettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbUserDeviceAutoSyncSettings
impl Debug for PbUserDeviceAutoSyncSettings
Sourceimpl Default for PbUserDeviceAutoSyncSettings
impl Default for PbUserDeviceAutoSyncSettings
Sourcefn default() -> PbUserDeviceAutoSyncSettings
fn default() -> PbUserDeviceAutoSyncSettings
Returns the “default value” for a type. Read more
Sourceimpl Message for PbUserDeviceAutoSyncSettings
impl Message for PbUserDeviceAutoSyncSettings
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbUserDeviceAutoSyncSettings
impl PartialEq for PbUserDeviceAutoSyncSettings
Sourcefn eq(&self, other: &PbUserDeviceAutoSyncSettings) -> bool
fn eq(&self, other: &PbUserDeviceAutoSyncSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PbUserDeviceAutoSyncSettings