pub struct PbUserDeviceJumpTestSettings {
pub cont_jump_duration: PbDuration,
}Fields
cont_jump_duration: PbDurationTrait Implementations
Sourceimpl Clone for PbUserDeviceJumpTestSettings
impl Clone for PbUserDeviceJumpTestSettings
Sourcefn clone(&self) -> PbUserDeviceJumpTestSettings
fn clone(&self) -> PbUserDeviceJumpTestSettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbUserDeviceJumpTestSettings
impl Debug for PbUserDeviceJumpTestSettings
Sourceimpl Default for PbUserDeviceJumpTestSettings
impl Default for PbUserDeviceJumpTestSettings
Sourcefn default() -> PbUserDeviceJumpTestSettings
fn default() -> PbUserDeviceJumpTestSettings
Returns the “default value” for a type. Read more
Sourceimpl Message for PbUserDeviceJumpTestSettings
impl Message for PbUserDeviceJumpTestSettings
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbUserDeviceJumpTestSettings
impl PartialEq for PbUserDeviceJumpTestSettings
Sourcefn eq(&self, other: &PbUserDeviceJumpTestSettings) -> bool
fn eq(&self, other: &PbUserDeviceJumpTestSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PbUserDeviceJumpTestSettings