pub struct PbUserDeviceSettings {Show 18 fields
pub general_settings: PbUserDeviceGeneralSettings,
pub alarm_settings: Option<PbUserDeviceAlarmSettings>,
pub countdown_settings: Option<PbUserDeviceCountdownSettings>,
pub jumptest_settings: Option<PbUserDeviceJumpTestSettings>,
pub interval_timer_settings: Option<PbUserIntervalTimerSettings>,
pub end_time_estimator_settings: Option<PbUserEndTimeEstimatorSettings>,
pub research_settings: Option<PbUserDeviceResearchSettings>,
pub safety_light_settings: Option<PbUserSafetyLightSettings>,
pub smart_watch_notification_settings: Option<PbUserSmartWatchNotificationSettings>,
pub map_settings: Option<PbUserMapSettings>,
pub rinse_dry_message_settings: Option<PbUserDeviceRinseDryMessageSettings>,
pub mass_storage_settings: Option<PbUserDeviceMassStorageSettings>,
pub do_not_disturb_settings: Option<PbUserDeviceDoNotDisturbSettings>,
pub auto_sync_settings: Option<PbUserDeviceAutoSyncSettings>,
pub automatic_sample_settings: Option<PbUserDeviceAutomaticSampleSettings>,
pub strava_segments_settings: Option<PbUserDeviceStravaSegmentsSettings>,
pub daylight_saving: Option<PbUserDeviceDaylightSaving>,
pub last_modified: PbSystemDateTime,
}Fields
general_settings: PbUserDeviceGeneralSettingsalarm_settings: Option<PbUserDeviceAlarmSettings>countdown_settings: Option<PbUserDeviceCountdownSettings>jumptest_settings: Option<PbUserDeviceJumpTestSettings>interval_timer_settings: Option<PbUserIntervalTimerSettings>end_time_estimator_settings: Option<PbUserEndTimeEstimatorSettings>research_settings: Option<PbUserDeviceResearchSettings>safety_light_settings: Option<PbUserSafetyLightSettings>smart_watch_notification_settings: Option<PbUserSmartWatchNotificationSettings>map_settings: Option<PbUserMapSettings>rinse_dry_message_settings: Option<PbUserDeviceRinseDryMessageSettings>mass_storage_settings: Option<PbUserDeviceMassStorageSettings>do_not_disturb_settings: Option<PbUserDeviceDoNotDisturbSettings>auto_sync_settings: Option<PbUserDeviceAutoSyncSettings>automatic_sample_settings: Option<PbUserDeviceAutomaticSampleSettings>strava_segments_settings: Option<PbUserDeviceStravaSegmentsSettings>daylight_saving: Option<PbUserDeviceDaylightSaving>last_modified: PbSystemDateTimeTrait Implementations
Sourceimpl Clone for PbUserDeviceSettings
impl Clone for PbUserDeviceSettings
Sourcefn clone(&self) -> PbUserDeviceSettings
fn clone(&self) -> PbUserDeviceSettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbUserDeviceSettings
impl Debug for PbUserDeviceSettings
Sourceimpl Default for PbUserDeviceSettings
impl Default for PbUserDeviceSettings
Sourcefn default() -> PbUserDeviceSettings
fn default() -> PbUserDeviceSettings
Returns the “default value” for a type. Read more
Sourceimpl Message for PbUserDeviceSettings
impl Message for PbUserDeviceSettings
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbUserDeviceSettings
impl PartialEq for PbUserDeviceSettings
impl StructuralPartialEq for PbUserDeviceSettings