pub struct PbUserPhysData {Show 17 fields
pub birthday: PbUserBirthday,
pub gender: PbUserGender,
pub weight: Option<PbUserWeight>,
pub height: Option<PbUserHeight>,
pub maximum_heartrate: Option<PbUserHrAttribute>,
pub resting_heartrate: Option<PbUserHrAttribute>,
pub obsolete_sitting_heartrate: Option<PbUserHrAttribute>,
pub aerobic_threshold: Option<PbUserHrAttribute>,
pub anaerobic_threshold: Option<PbUserHrAttribute>,
pub vo2max: Option<PbUserVo2Max>,
pub training_background: Option<PbUserTrainingBackground>,
pub typical_day: Option<PbUserTypicalDay>,
pub weekly_recovery_time_sum: Option<PbWeeklyRecoveryTimeSum>,
pub speed_calibration_offset: Option<PbSpeedCalibrationOffset>,
pub functional_threshold_power: Option<PbUserFunctionalThresholdPower>,
pub last_modified: Option<PbSystemDateTime>,
pub snapshot_start_time: Option<PbLocalDateTime>,
}Fields
birthday: PbUserBirthdaygender: PbUserGenderweight: Option<PbUserWeight>height: Option<PbUserHeight>maximum_heartrate: Option<PbUserHrAttribute>resting_heartrate: Option<PbUserHrAttribute>obsolete_sitting_heartrate: Option<PbUserHrAttribute>aerobic_threshold: Option<PbUserHrAttribute>anaerobic_threshold: Option<PbUserHrAttribute>vo2max: Option<PbUserVo2Max>training_background: Option<PbUserTrainingBackground>typical_day: Option<PbUserTypicalDay>weekly_recovery_time_sum: Option<PbWeeklyRecoveryTimeSum>speed_calibration_offset: Option<PbSpeedCalibrationOffset>functional_threshold_power: Option<PbUserFunctionalThresholdPower>last_modified: Option<PbSystemDateTime>snapshot_start_time: Option<PbLocalDateTime>Trait Implementations
Sourceimpl Clone for PbUserPhysData
impl Clone for PbUserPhysData
Sourcefn clone(&self) -> PbUserPhysData
fn clone(&self) -> PbUserPhysData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbUserPhysData
impl Debug for PbUserPhysData
Sourceimpl Default for PbUserPhysData
impl Default for PbUserPhysData
Sourcefn default() -> PbUserPhysData
fn default() -> PbUserPhysData
Returns the “default value” for a type. Read more
Sourceimpl Message for PbUserPhysData
impl Message for PbUserPhysData
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbUserPhysData
impl PartialEq for PbUserPhysData
impl StructuralPartialEq for PbUserPhysData