PbDataType

Enum PbDataType 

#[repr(i32)]
pub enum PbDataType {
Show 52 variants TypeUndefined = 0, TypeInherited = 1, TypeEnum = 2, TypeMillis = 3, TypeSecond = 4, TypeMinute = 5, TypeHour = 6, TypeHours = 7, TypeDay = 8, TypeMonth = 9, TypeYear = 10, TypeWeight = 11, TypeHeight = 12, TypeVo2max = 13, TypeHeartrate = 20, TypeHrPercent = 21, TypeHrReserve = 22, TypeSpeed = 23, TypeCadence = 24, TypeAltitude = 25, TypePower = 26, TypePowerLrb = 27, TypePowerPi = 28, TypeTemperature = 29, TypeActivity = 30, TypeStrideLength = 31, TypeIncline = 32, TypeDecline = 33, TypeDistance = 52, TypeEnergy = 53, TypeFatPercents = 54, TypeAscent = 55, TypeDescent = 56, TypeLatitude = 57, TypeLongitude = 58, TypeHertz = 59, TypePercent = 60, TypeCumulatedActivityDay = 61, TypeRunningIndex = 62, TypeRrInterval = 63, TypeZIndex = 64, TypeExerciseTargetIndex = 65, TypeTimeZoneOffset = 66, TypeWheelSize = 67, TypeFitnessClass = 68, TypeAcceleration = 69, TypeCrankLength = 70, TypeAngleDegree = 71, TypeNewton = 72, TypeFunctionalThresholdPower = 73, TypeCalories = 74, TypeSpeedCalibrationOffset = 75,
}

Variants



TypeUndefined = 0



TypeInherited = 1



TypeEnum = 2



TypeMillis = 3



TypeSecond = 4



TypeMinute = 5



TypeHour = 6



TypeHours = 7



TypeDay = 8



TypeMonth = 9



TypeYear = 10



TypeWeight = 11



TypeHeight = 12



TypeVo2max = 13



TypeHeartrate = 20



TypeHrPercent = 21



TypeHrReserve = 22



TypeSpeed = 23



TypeCadence = 24



TypeAltitude = 25



TypePower = 26



TypePowerLrb = 27



TypePowerPi = 28



TypeTemperature = 29



TypeActivity = 30



TypeStrideLength = 31



TypeIncline = 32



TypeDecline = 33



TypeDistance = 52



TypeEnergy = 53



TypeFatPercents = 54



TypeAscent = 55



TypeDescent = 56



TypeLatitude = 57



TypeLongitude = 58



TypeHertz = 59



TypePercent = 60



TypeCumulatedActivityDay = 61



TypeRunningIndex = 62



TypeRrInterval = 63



TypeZIndex = 64



TypeExerciseTargetIndex = 65



TypeTimeZoneOffset = 66



TypeWheelSize = 67



TypeFitnessClass = 68



TypeAcceleration = 69



TypeCrankLength = 70



TypeAngleDegree = 71



TypeNewton = 72



TypeFunctionalThresholdPower = 73



TypeCalories = 74



TypeSpeedCalibrationOffset = 75

Implementations

Source

impl PbDataType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of PbDataType.

pub fn from_i32(value: i32) -> Option<PbDataType>

Converts an i32 to a PbDataType, or None if value is not a valid variant.