pub struct PbSystemDateTime {
pub date: PbDate,
pub time: PbTime,
pub trusted: bool,
}Fields
date: PbDatetime: PbTimetrusted: boolTrait Implementations
Sourceimpl Clone for PbSystemDateTime
impl Clone for PbSystemDateTime
Sourcefn clone(&self) -> PbSystemDateTime
fn clone(&self) -> PbSystemDateTime
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbSystemDateTime
impl Debug for PbSystemDateTime
Sourceimpl Default for PbSystemDateTime
impl Default for PbSystemDateTime
Sourcefn default() -> PbSystemDateTime
fn default() -> PbSystemDateTime
Returns the “default value” for a type. Read more
Sourceimpl Message for PbSystemDateTime
impl Message for PbSystemDateTime
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PbSystemDateTime
impl PartialEq for PbSystemDateTime
impl StructuralPartialEq for PbSystemDateTime