pub struct PbTrainingSessionTargetId {
pub value: u64,
pub last_modified: Option<PbSystemDateTime>,
}Fields
value: u64last_modified: Option<PbSystemDateTime>Trait Implementations
Sourceimpl Clone for PbTrainingSessionTargetId
impl Clone for PbTrainingSessionTargetId
Sourcefn clone(&self) -> PbTrainingSessionTargetId
fn clone(&self) -> PbTrainingSessionTargetId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PbTrainingSessionTargetId
impl Debug for PbTrainingSessionTargetId
Sourceimpl Default for PbTrainingSessionTargetId
impl Default for PbTrainingSessionTargetId
Sourcefn default() -> PbTrainingSessionTargetId
fn default() -> PbTrainingSessionTargetId
Returns the “default value” for a type. Read more
Sourceimpl Message for PbTrainingSessionTargetId
impl Message for PbTrainingSessionTargetId
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for PbTrainingSessionTargetId